@@ -2,7 +2,7 @@
 DSLIBRARY - run your data science code anywhere.
 
 """
-__version__ = "0.0.1"
+__version__ = "0.0.3"
 
 # environment variables
 from .front import ENV_DSLIBRARY_TARGET, ENV_DSLIBRARY_SPEC, ENV_DSLIBRARY_TOKEN
@@ -41,7 +41,7 @@ def instance():
 
     :returns:  An instance of the MMLibrary() base class.
     """
-    from .to_local import DSLibraryLocal
+    from .transport.to_local import DSLibraryLocal
     from .transport.to_rest import DSLibraryViaREST
     from .transport.to_volume import DSLibraryViaVolume
     from .transport.to_mmlibrary import DSLibraryViaMMLibrary
@@ -84,3 +84,33 @@ def instance():
         return cls(*args, **kwargs)
     except ImportError:
         raise ValueError(f"Unrecognized {ENV_DSLIBRARY_TARGET} implementation: {target_parts[0]}")
+
+
+# set up default methods
+_DEFAULT = instance()
+get_parameter = _DEFAULT.get_parameter
+get_parameters = _DEFAULT.get_parameters
+load_dataframe = _DEFAULT.load_dataframe
+open_resource = _DEFAULT.open_resource
+write_resource = _DEFAULT.write_resource
+log_metric = _DEFAULT.log_metric
+log_metrics = _DEFAULT.log_metrics
+log_param = _DEFAULT.log_param
+log_artifact = _DEFAULT.log_artifact
+log_artifacts = _DEFAULT.log_artifacts
+log_dict = _DEFAULT.log_dict
+log_text = _DEFAULT.log_text
+get_sql_connection = _DEFAULT.get_sql_connection
+open_run_data = _DEFAULT.open_run_data
+set_evaluation_result = _DEFAULT.set_evaluation_result
+open_model_binary = _DEFAULT.open_model_binary
+read_resource = _DEFAULT.read_resource
+start_run = _DEFAULT.start_run
+end_run = _DEFAULT.end_run
+active_run = _DEFAULT.active_run
+get_metadata = _DEFAULT.get_metadata
+get_uri = _DEFAULT.get_uri
+get_last_metric = _DEFAULT.get_last_metric
+load_pickled_model = _DEFAULT.load_pickled_model
+save_pickled_model = _DEFAULT.save_pickled_model
+# TODO there may be more methods to add here
