@@ -9,6 +9,7 @@ import pickle
 import uuid
 import sys
 import pandas
+import numpy
 import time
 import typing
 from collections import namedtuple
@@ -289,7 +290,7 @@ class DSLibrary(object):
             "value": value
         }
         df = pandas.DataFrame(data=[row])
-        self.write_resource(PARAMS_ALIAS, df, append=True, uri="params.json", format="json")
+        self.write_resource(PARAMS_ALIAS, df, append=True)
 
     def log_params(self, params: dict):
         """
@@ -317,7 +318,7 @@ class DSLibrary(object):
             "step": step
         }
         df = pandas.DataFrame(data=[row])
-        self.write_resource(METRICS_ALIAS, df, append=True, uri="metrics.json", format="json")
+        self.write_resource(METRICS_ALIAS, df, append=True)
 
     def log_metrics(self, metrics: dict, step: int=0) -> None:
         """
@@ -326,9 +327,9 @@ class DSLibrary(object):
         for k, v in (metrics or {}).items():
             self.log_metric(k, v, step)
 
-    def get_metrics(self, metric_name: str = None, uri: str = None, time_range: (list, tuple) = None, limit: int = None) -> typing.Iterable:
+    def get_metrics(self, metric_name: str = None, uri: str = None, time_range: (list, tuple) = None, limit: int = None):
         """
-        Retrieve the values of previously stored metrics.  Implementations might limit which metrics are returned
+        Retrieve the values of previously stored metrics as a dataframe.  Implementations might limit which metrics are returned
         based on security policies.  Sort order should be by time, descending.
 
         :param metric_name:     Limits results to a particular named metric.
@@ -343,10 +344,7 @@ class DSLibrary(object):
             # TODO to support this would require creating a client, using the run ID to look them up, etc.
             raise DSLibraryException("Access to metrics in mlflow is not supported at this time.")
         # load metrics
-        try:
-            df = self.load_dataframe(METRICS_ALIAS)
-        except FileNotFoundError:
-            return
+        df = self.load_dataframe(METRICS_ALIAS)
         # filter by criteria, sort most recent first, limit to requested number of samples
         if time_range:
             df = df[time_range[0] <= df.time < time_range[1]]
@@ -357,16 +355,16 @@ class DSLibrary(object):
         df.sort_values(by=["time"], ascending=False)
         if limit:
             df = df.head(limit)
-        for row in df.itertuples(index=False, name=None):
-            metric = DSLibrary.Metric(run_id=row.run_id, uri=row.uri, user=row.user, time=row.time, name=row.name, value=row.value, step=row.step)
-            yield metric
+        return df
 
     def get_last_metric(self, metric_name: str):
         """
         Get the most recently saved metric of the given name for the current model.
         """
-        metrics = list(self.get_metrics(metric_name, uri=self.get_uri(), limit=1))
-        return metrics[0] if metrics else None
+        metrics = self.get_metrics(metric_name, uri=self.get_uri(), limit=1)
+        if metrics.shape[0]:
+            row = metrics.iloc[0]
+            return DSLibrary.Metric(**row)
 
     def log_text(self, text: str, artifact_file: str):
         """
@@ -480,6 +478,8 @@ class DSLibrary(object):
         resource_spec.update((self._spec.get("outputs") or {}).get(resource_name) or {})
         resource_name_xlt = resource_spec.pop("uri", None) or resource_name
         file_extension = os.path.splitext(resource_name_xlt)[1].strip(".")
+        if not file_extension:
+            self._default_format_for_aliases(resource_name, resource_spec)
         format = resource_spec.pop("format", None) or file_extension
         # NOTE: specs take precedence over kwargs, making model-supplied values effectively only defaults
         format_options = dict(resource_spec.get("format_options") or {})
@@ -493,6 +493,11 @@ class DSLibrary(object):
             # TODO detect nosql (nosql_collection) and write data there
             raise DSLibraryException("NoSQL write of columnar data is not yet implemented")
         # TODO support for time series databases
+        # we detect numpy arrays, series, etc., and save them as a dataframe with one column
+        if isinstance(content, (pandas.Series, numpy.ndarray, pandas.Index)):
+            series = content
+            content = pandas.DataFrame()
+            content[resource_name] = series
         # send (pandas) DataFrame as CSV/etc.
         df_format = format if format in PANDAS_WRITE_FORMATS else "csv"
         if hasattr(content, PANDAS_WRITE_FORMATS[df_format]):
@@ -667,6 +672,8 @@ class DSLibrary(object):
         # TODO we should offer a validation option that checks the data types against the schema
         # format can be specified, or file extension will be used
         file_extension = os.path.splitext(resource_name_xlt)[1].strip(".")
+        if not file_extension:
+            self._default_format_for_aliases(resource_name, kwargs)
         format = kwargs.pop("format", None) or file_extension
         # options for read function can be given
         format_options = kwargs.pop("format_options", None) or {}
@@ -677,6 +684,19 @@ class DSLibrary(object):
         # TODO support read from folder, i.e. folder of CSVs, parquet, etc.
         raise DSLibraryException(f"file type not supported: {format}")
 
+    def _default_format_for_aliases(self, resource_name: str, options: dict):
+        """
+        Fill in default format for the built-in aliases.
+        """
+        if not options.get("format") and resource_name in (METRICS_ALIAS, PARAMS_ALIAS):
+            options["format"] = "json"
+            if "format_options" in options:
+                format_options = options["format_options"]
+            else:
+                format_options = options["format_options"] = {}
+            if "lines" not in format_options:
+                format_options["lines"] = True
+
     def load_pickled_model(self, part: str=None):
         """
         Un-pickle a saved model from the default model binary, or from one of its named parts.
