@@ -2,6 +2,7 @@
 Run a model.
 """
 import json
+import inspect
 import os
 import typing
 import subprocess
@@ -27,14 +28,14 @@ class ModelRunner(object):
         :param user:            Which user is running the model.
         :param run_id:          Run ID needs to be specified when running in MLFlow.
         :param entry_point:     Which entry point is being called.
-        :param mlflow:          MLFlow-related settings.
+        :param mlflow:          MLFlow-related settings.  True = send all to mlflow, {} = send some calls to mlflow.
         """
         self.uri = uri or ""
         self.user = user or ""
         self.run_id = run_id or ""
         self.entry_point = entry_point
         # TODO document & validate these
-        self.mlflow = mlflow or {}
+        self.mlflow = mlflow if isinstance(mlflow, dict) else {"all": True} if mlflow is True else {}
         self.inputs = {}
         self.outputs = {}
         self.parameters = {}
@@ -142,8 +143,18 @@ class ModelRunner(object):
         orig_env = {ENV_DSLIBRARY_TARGET: os.environ.get(ENV_DSLIBRARY_TARGET), ENV_DSLIBRARY_SPEC: os.environ.get(ENV_DSLIBRARY_SPEC)}
         os.environ[ENV_DSLIBRARY_TARGET] = f"local:{path or '.'}"
         os.environ[ENV_DSLIBRARY_SPEC] = json.dumps(self._generate_spec())
+        # map parameters to method signature
+        call_kwargs = {}
+        sig = inspect.signature(method)
+        for p_name in sig.parameters:
+            if p_name in self.parameters:
+                param = sig.parameters[p_name]
+                value = self.parameters[p_name]
+                if param.annotation:
+                    value = param.annotation(value)
+                call_kwargs[p_name] = value
         # the method makes calls to dslibrary, following rules set above
-        method()
+        method(**call_kwargs)
         # restore environment
         for k, v in orig_env.items():
             os.environ[k] = v or ""
